@@ -26,8 +26,7 @@
 class KTimeComboBox;
 class KDateComboBox;
 
-namespace SendLater
-{
+namespace SendLater {
 class SendLaterTimeDateWidget : public QWidget
 {
     Q_OBJECT
